summaryrefslogtreecommitdiff
path: root/TAO/orbsvcs/orbsvcs/Naming/Persistent_Context_Index.h
diff options
context:
space:
mode:
Diffstat (limited to 'TAO/orbsvcs/orbsvcs/Naming/Persistent_Context_Index.h')
-rw-r--r--TAO/orbsvcs/orbsvcs/Naming/Persistent_Context_Index.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/TAO/orbsvcs/orbsvcs/Naming/Persistent_Context_Index.h b/TAO/orbsvcs/orbsvcs/Naming/Persistent_Context_Index.h
index f3d03911b75..2b60b3ede0f 100644
--- a/TAO/orbsvcs/orbsvcs/Naming/Persistent_Context_Index.h
+++ b/TAO/orbsvcs/orbsvcs/Naming/Persistent_Context_Index.h
@@ -99,8 +99,8 @@ public:
CORBA::ORB_ptr orb (void);
// Return orb pointer.
- CosNaming::NamingContext_ptr root_context (void);
- // Return a pointer to the root Naming Context (returns a copy - must be
+ char *root_ior (void);
+ // Return ior of the root Naming Context (returns a copy - must be
// deallocated by the user).
private:
@@ -143,8 +143,8 @@ private:
// POA under which to register Persistent Naming Context servants
// during start-up.
- CosNaming::NamingContext_var root_context_;
- // The reference to the root Naming Context.
+ CORBA::String_var root_ior_;
+ // The ior of the root Naming Context.
};
#endif /* TAO_PERSISTENT_CONTEXT_INDEX_H */